<?php if ( ! defined('BASEPATH')) exit('No direct script access allowed');

require_once PATH_THIRD.'mountee_3/helper.php';

class Mountee_3_mcp
{

	var $helper;

	function __construct()
	{
		ee()->load->library('logger');
		$this->helper = new Helper();
	}

	function index()
	{
		ee()->cp->load_package_css('mountee3');

		$settings = Mountee_settings::get_settings();
		
		$action_id  = ee()->cp->fetch_action_id('Mountee_3_mcp', 'process_request');
		$vars = array(
			'cp_page_title'			=> lang('mountee_settings_title'),
			'save_tmpl_as_files'	=> ee()->config->item('save_tmpl_files'),
			'action_id'				=> $action_id,
			'username'				=> ee()->session->userdata('username'),
			'site_name'				=> ee()->config->item('site_name'),
			'action_url'			=> ee()->config->item('site_url').'?ACT='.$action_id,
			'base_url'				=> ee('CP/URL', 'addons/settings/mountee_3')->compile(),
			'save_btn_text'			=> lang('settings_save'),
			'save_btn_text_working' => lang('settings_save_working'),
		);

		$vars['sections'] = array(
			array(
				array(
					'title' => 'mountee_license',
					'desc' => 'mountee_license_desc',
					'fields' => array(
						'mountee_license' => array('type' => 'text', 'value' => $settings['mountee_license'])
					)
				),
				array(
					'title' => '',
					'fields' => array(
						'action' => array('type' => 'hidden', 'value' => 'save_settings')
					)
				),
			)
		);

		if (ee()->input->post('action') == "save_settings")
		{
			$settings = array();
			$form_is_valid = TRUE;

			// Validation
			$validator = ee('Validation')->make();
			$result = $validator->validate($_POST);

			if ($result->isValid())
			{
				// Get back all values, store them in array and save them
				$fields = array();
				foreach ($vars['sections'] as $settings)
				{
					foreach ($settings as $setting)
					{
						foreach ($setting['fields'] as $field_name => $field)
						{
							$fields[$field_name] = ee()->input->post($field_name);
						}
					}
				}
				// We don't want to save that field, it's not a setting
				unset($fields['action']);

				Mountee_settings::save_settings($fields);

				ee('CP/Alert')->makeInline('shared-form')
						->asSuccess()
						->withTitle(lang('settings_saved'))
						->addToBody(lang('settings_saved_desc'))
						->defer();

				ee()->functions->redirect(ee('CP/URL', 'addons/settings/mountee_3')->compile());
			}
			else
			{
				$vars['errors'] = $result;
				ee('CP/Alert')->makeInline('shared-form')
					->asIssue()
					->withTitle(lang('settings_save_error'))
					->addToBody(lang('settings_save_error_desc'))
					->now();
				$vars["settings"] = $settings;
			}
		}
		
		// return ee()->load->view('index', $vars, TRUE);
		return array(
			'heading'		=> lang('nav_settings'),
			'body'			=> ee('View')->make('mountee_3:index')->render($vars),
			'breadcrumb'	=> array(
				ee('CP/URL', 'addons/settings/mountee_3')->compile() => lang('mountee_3_module_name')
			),
		);
	}

	/**
	 * This function is called when Mountee app is sending a query
	 * @return [type] [description]
	 */
	function process_request()
	{
		$method = ee()->input->get('m');

		switch ($method) {
			case 'status':
				$this->helper->get_status();
				break;
			
			case 'login':
				$this->helper->login();
				break;
			
			case 'logout':
				$this->helper->logout();
				break;

			case 'list_all':
				$this->helper->list_all();
				break;
			
			case 'create_template_group':
				$this->helper->create_template_group();
				break;

			case 'create_template':
				$this->helper->create_template();
				break;
			
			case 'get_template':
				$this->helper->get_template();
				break;
			
			case 'update_template_data':
				$this->helper->update_template_data();
				break;
			
			case 'move_template':
				$this->helper->move_template();
				break;
			
			case 'delete_template_group':
				$this->helper->delete_template_group();
				break;
			
			case 'delete_template':
				$this->helper->delete_template();
				break;
			
			case 'rename_template_group':
				$this->helper->rename_template_group();
				break;
			
			case 'rename_template':
				$this->helper->rename_template();
				break;
			
			default:
				// Shouldn't be here... Send an error

				break;
		} 
	}

}
